GasThermo
=========

A package for obtaining gas-phase thermodynamic properties and computing integrals.
Designed for integration with computational simulation environments.

<p align="center"> 
    <img 
        src="THF-WATER.png" 
        width="300"
    />
</p>

Tutorial
========
A tutorial can be found [here](tutorial.ipynb)

Documentation
=============
The online documentation is hosted at [read the docs](https://gasthermo.readthedocs.io/en/master/).

Contributing
============
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.
